@@ -26,7 +26,8 @@ pub fn encrypt_file(input: &str, output: &str, keyfile: &str, sha_sum: bool) ->
         let answer = get_answer(
             "Output file already exists, would you like to overwrite?",
             true,
-        )?;
+        )
+        .context("Unable to read provided answer")?;
         if !answer {
             exit(0);
         }
@@ -85,6 +86,9 @@ pub fn encrypt_file(input: &str, output: &str, keyfile: &str, sha_sum: bool) ->
     let encrypted_bytes = cipher
         .encrypt(nonce, data.as_slice())
         .expect("Unable to encrypt the data");
+
+    drop(data);
+
     let encrypted_bytes_base64 = base64::encode(encrypted_bytes);
     let salt_base64 = base64::encode(salt);
     let nonce_base64 = base64::encode(nonce);
@@ -101,8 +105,12 @@ pub fn encrypt_file(input: &str, output: &str, keyfile: &str, sha_sum: bool) ->
 
     let duration = start_time.elapsed();
 
-    println!("Encryption successful - written to {}", output);
-    println!("That took {:.2}s", duration.as_secs_f32());
+    println!(
+        "Encryption successful - written to {} [took {:.2}s]",
+        output,
+        duration.as_secs_f32()
+    );
+
     if sha_sum {
         let mut hasher = Sha3_512::new();
         serde_json::to_writer(&mut hasher, &data).context("Can't write to the sha3-512 hasher")?;
